@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Mercurial::Push;
-BEGIN {
-  $Dist::Zilla::Plugin::Mercurial::Push::VERSION = '0.03';
+{
+  $Dist::Zilla::Plugin::Mercurial::Push::VERSION = '0.04';
 }
 
 use strict;
@@ -25,7 +25,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Push the current Mercurial branch
 
-
+__END__
 
 =pod
 
@@ -35,7 +35,7 @@ Dist::Zilla::Plugin::Mercurial::Push - Push the current Mercurial branch
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -51,7 +51,7 @@ Once the release is done, this plugin will push current Mercurial branch.
 
 =head1 AUTHOR
 
-  Dave Rolsky <autarch@urth.org>
+Shlomi Fish <shlomif@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -61,7 +61,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
