@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Mercurial::Tag;
-BEGIN {
-  $Dist::Zilla::Plugin::Mercurial::Tag::VERSION = '0.03';
+{
+  $Dist::Zilla::Plugin::Mercurial::Tag::VERSION = '0.04';
 }
 
 use strict;
@@ -42,7 +42,7 @@ sub after_release {
 
 # ABSTRACT: Tag the new version
 
-
+__END__
 
 =pod
 
@@ -52,7 +52,7 @@ Dist::Zilla::Plugin::Mercurial::Tag - Tag the new version
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -74,7 +74,7 @@ After the release, it adds a tag with the released version.
 
 =head1 AUTHOR
 
-  Dave Rolsky <autarch@urth.org>
+Shlomi Fish <shlomif@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -84,7 +84,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
